import { defineStore } from 'pinia'
import { ref, computed } from 'vue'

export interface Job {
  id: string
  title: string
  department: string
  location: string
  description: string
  status: 'active' | 'paused' | 'draft'
  pendingResumes: number
  passedResumes: number
  aiCriteria: {
    education: { condition: string; value: string; weight: number }
    experience: { condition: string; value: string; weight: number }
    skills: { condition: string; value: string; weight: number }
    language: { condition: string; value: string; weight: number }
  }
  createdAt: Date
  updatedAt: Date
}

export interface Candidate {
  id: string
  name: string
  jobId: string
  jobTitle: string
  matchScore: number
  status: 'pending' | 'passed' | 'rejected' | 'interviewed'
  highlights: string[]
  concerns: string[]
  summary: string
  resumeText: string
  education: string
  experience: string
  skills: string[]
  submittedAt: Date
  reviewedAt?: Date
}

export interface Interview {
  id: string
  title: string
  description: string
  questions: string[]
  duration: number
  createdAt: Date
}

export const useJobStore = defineStore('job', () => {
  // 状态
  const jobs = ref<Job[]>([])
  const candidates = ref<Candidate[]>([])
  const interviews = ref<Interview[]>([])
  const isModalOpen = ref(false)
  const isLoading = ref(false)
  const currentJob = ref<Job | null>(null)
  const currentCandidate = ref<Candidate | null>(null)

  // 计算属性
  const activeJobs = computed(() => 
    jobs.value.filter(job => job.status === 'active')
  )

  const totalPendingResumes = computed(() =>
    jobs.value.reduce((sum, job) => sum + job.pendingResumes, 0)
  )

  const totalCandidates = computed(() => candidates.value.length)

  const pendingCandidates = computed(() =>
    candidates.value.filter(candidate => candidate.status === 'pending')
  )

  const passedCandidates = computed(() =>
    candidates.value.filter(candidate => candidate.status === 'passed')
  )

  const rejectedCandidates = computed(() =>
    candidates.value.filter(candidate => candidate.status === 'rejected')
  )

  const interviewedCandidates = computed(() =>
    candidates.value.filter(candidate => candidate.status === 'interviewed')
  )

  const getCandidatesByJob = computed(() => (jobId: string) =>
    candidates.value.filter(candidate => candidate.jobId === jobId)
  )

  const getJobById = computed(() => (jobId: string) =>
    jobs.value.find(job => job.id === jobId)
  )

  // 统计数据
  const dashboardStats = computed(() => ({
    totalJobs: jobs.value.length,
    activeJobs: activeJobs.value.length,
    totalCandidates: totalCandidates.value,
    pendingCandidates: pendingCandidates.value.length,
    passedCandidates: passedCandidates.value.length,
    rejectedCandidates: rejectedCandidates.value.length,
    interviewedCandidates: interviewedCandidates.value.length,
    averageMatchScore: candidates.value.length > 0 
      ? Math.round(candidates.value.reduce((sum, c) => sum + c.matchScore, 0) / candidates.value.length)
      : 0,
    passRate: candidates.value.length > 0 
      ? Math.round((passedCandidates.value.length / candidates.value.length) * 100)
      : 0
  }))

  // 动作
  const initializeData = () => {
    // 模拟初始数据
    jobs.value = [
      {
        id: '1',
        title: 'Vue.js前端工程师',
        department: '技术部',
        location: '上海',
        description: '负责前端产品开发，具备Vue.js、TypeScript等技术栈经验',
        status: 'active',
        pendingResumes: 12,
        passedResumes: 3,
        aiCriteria: {
          education: { condition: '>=', value: '本科', weight: 20 },
          experience: { condition: '>=', value: '3年', weight: 30 },
          skills: { condition: 'includes', value: 'Vue.js,TypeScript', weight: 35 },
          language: { condition: '>=', value: '英语四级', weight: 15 }
        },
        createdAt: new Date('2024-01-15'),
        updatedAt: new Date('2024-01-20')
      },
      {
        id: '2',
        title: 'Java后端工程师',
        department: '技术部',
        location: '北京',
        description: '负责后端服务开发，熟悉Spring Boot、微服务架构',
        status: 'active',
        pendingResumes: 8,
        passedResumes: 5,
        aiCriteria: {
          education: { condition: '>=', value: '本科', weight: 25 },
          experience: { condition: '>=', value: '5年', weight: 35 },
          skills: { condition: 'includes', value: 'Java,Spring Boot,MySQL', weight: 30 },
          language: { condition: '>=', value: '英语四级', weight: 10 }
        },
        createdAt: new Date('2024-01-10'),
        updatedAt: new Date('2024-01-18')
      },
      {
        id: '3',
        title: 'UI/UX设计师',
        department: '设计部',
        location: '深圳',
        description: '负责产品界面和用户体验设计',
        status: 'active',
        pendingResumes: 15,
        passedResumes: 2,
        aiCriteria: {
          education: { condition: '>=', value: '专科', weight: 15 },
          experience: { condition: '>=', value: '2年', weight: 25 },
          skills: { condition: 'includes', value: 'Figma,Sketch,Adobe', weight: 45 },
          language: { condition: '>=', value: '无要求', weight: 15 }
        },
        createdAt: new Date('2024-01-12'),
        updatedAt: new Date('2024-01-19')
      }
    ]

    candidates.value = [
      {
        id: '1',
        name: '张小明',
        jobId: '1',
        jobTitle: 'Vue.js前端工程师',
        matchScore: 88,
        status: 'pending',
        highlights: ['5年Vue.js开发经验', '熟悉TypeScript', '有大型项目经验', '具备团队协作能力'],
        concerns: ['缺少移动端开发经验', '团队管理经验不足'],
        summary: '具备扎实的前端技术基础，Vue.js经验丰富，适合高级前端开发岗位。在技术深度和项目经验方面表现出色，但在移动端开发和团队管理方面还有提升空间。',
        education: '本科 - 计算机科学与技术',
        experience: '5年前端开发经验',
        skills: ['Vue.js', 'TypeScript', 'JavaScript', 'CSS3', 'Webpack'],
        resumeText: '张小明，本科学历，计算机科学专业毕业。拥有5年前端开发经验，精通Vue.js、TypeScript等现代前端技术栈。曾在多家互联网公司担任前端工程师，参与过多个大型项目的开发...',
        submittedAt: new Date('2024-01-20')
      },
      {
        id: '2',
        name: '李小红',
        jobId: '1',
        jobTitle: 'Vue.js前端工程师',
        matchScore: 75,
        status: 'pending',
        highlights: ['3年前端开发经验', '熟悉React和Vue.js', '有组件库开发经验'],
        concerns: ['TypeScript经验较少', '项目规模偏小', '缺少性能优化经验'],
        summary: '前端基础良好，技术栈匹配度较高，有一定成长潜力。在组件化开发方面有实践经验，但在TypeScript和大型项目经验方面需要进一步提升。',
        education: '本科 - 软件工程',
        experience: '3年前端开发经验',
        skills: ['Vue.js', 'React', 'JavaScript', 'HTML5', 'CSS3'],
        resumeText: '李小红，本科学历，软件工程专业。3年前端开发经验，熟悉Vue.js和React框架，有组件库开发经验...',
        submittedAt: new Date('2024-01-19')
      },
      {
        id: '3',
        name: '王大强',
        jobId: '2',
        jobTitle: 'Java后端工程师',
        matchScore: 92,
        status: 'passed',
        highlights: ['8年Java开发经验', '精通Spring Boot', '有微服务架构经验', '熟悉分布式系统'],
        concerns: ['缺少云原生经验', '团队规模相对较小'],
        summary: '资深Java后端工程师，技术功底扎实，项目经验丰富。在微服务架构和分布式系统方面有深入理解，是团队的技术骨干候选人。',
        education: '硕士 - 计算机科学',
        experience: '8年Java后端开发经验',
        skills: ['Java', 'Spring Boot', 'MySQL', 'Redis', 'Kafka'],
        resumeText: '王大强，硕士学历，8年Java后端开发经验。精通Spring Boot框架，有丰富的微服务架构设计和实施经验...',
        submittedAt: new Date('2024-01-18'),
        reviewedAt: new Date('2024-01-19')
      },
      {
        id: '4',
        name: '陈小美',
        jobId: '3',
        jobTitle: 'UI/UX设计师',
        matchScore: 85,
        status: 'interviewed',
        highlights: ['4年UI/UX设计经验', '精通Figma和Sketch', '有B端产品设计经验', '用户体验思维强'],
        concerns: ['缺少移动端设计经验', '技术理解需要加强'],
        summary: '优秀的UI/UX设计师，设计功底扎实，用户体验意识强。在B端产品设计方面有丰富经验，但在移动端设计和技术理解方面还有提升空间。',
        education: '本科 - 视觉传达设计',
        experience: '4年UI/UX设计经验',
        skills: ['Figma', 'Sketch', 'Adobe Creative Suite', 'Principle', 'Axure'],
        resumeText: '陈小美，本科学历，视觉传达设计专业。4年UI/UX设计经验，精通各类设计工具，有丰富的B端产品设计经验...',
        submittedAt: new Date('2024-01-17'),
        reviewedAt: new Date('2024-01-18')
      },
      {
        id: '5',
        name: '刘小刚',
        jobId: '2',
        jobTitle: 'Java后端工程师',
        matchScore: 65,
        status: 'rejected',
        highlights: ['2年Java开发经验', '熟悉Spring框架'],
        concerns: ['经验不足', '缺少大型项目经验', '技术深度有限', '沟通能力待提升'],
        summary: '初级Java开发工程师，基础技能掌握良好，但经验和技术深度不足以满足当前岗位要求。建议继续积累项目经验后再申请。',
        education: '专科 - 计算机应用技术',
        experience: '2年Java开发经验',
        skills: ['Java', 'Spring', 'MySQL', 'HTML', 'CSS'],
        resumeText: '刘小刚，专科学历，2年Java开发经验。熟悉Spring框架，参与过小型项目开发...',
        submittedAt: new Date('2024-01-16'),
        reviewedAt: new Date('2024-01-17')
      }
    ]

    interviews.value = [
      {
        id: '1',
        title: 'Vue.js前端工程师初面',
        description: '主要考察前端基础知识和Vue.js技术栈',
        questions: [
          'Vue 3的Composition API相比Options API有什么优势？',
          '请解释Vue的响应式原理',
          '如何优化Vue应用的性能？',
          '描述一个你负责的复杂前端项目'
        ],
        duration: 60,
        createdAt: new Date('2024-01-15')
      },
      {
        id: '2',
        title: 'Java后端工程师技术面试',
        description: '重点考察Java技术栈和系统设计能力',
        questions: [
          'Spring Boot的自动配置原理是什么？',
          '如何设计一个高并发的秒杀系统？',
          'MySQL的索引优化策略有哪些？',
          '微服务架构的优缺点是什么？'
        ],
        duration: 90,
        createdAt: new Date('2024-01-12')
      }
    ]
  }

  const addJob = (jobData: Omit<Job, 'id' | 'createdAt' | 'updatedAt'>) => {
    const newJob: Job = {
      ...jobData,
      id: Date.now().toString(),
      createdAt: new Date(),
      updatedAt: new Date()
    }
    jobs.value.push(newJob)
  }

  const updateJob = (jobId: string, updates: Partial<Job>) => {
    const index = jobs.value.findIndex(job => job.id === jobId)
    if (index !== -1) {
      jobs.value[index] = {
        ...jobs.value[index],
        ...updates,
        updatedAt: new Date()
      }
    }
  }

  const triggerScreening = async (jobId: string) => {
    const job = jobs.value.find(j => j.id === jobId)
    if (!job) return

    isLoading.value = true
    
    // 模拟AI筛选过程
    await new Promise(resolve => setTimeout(resolve, 2000))
    
    // 更新简历数量
    job.pendingResumes = 0
    job.passedResumes += Math.floor(Math.random() * 3) + 1
    job.updatedAt = new Date()
    
    isLoading.value = false
  }

  const updateCandidateStatus = (candidateId: string, status: Candidate['status']) => {
    const candidate = candidates.value.find(c => c.id === candidateId)
    if (candidate) {
      candidate.status = status
      candidate.reviewedAt = new Date()
    }
  }

  const batchScreenCandidates = async (candidateIds: string[]) => {
    isLoading.value = true
    
    // 模拟批量筛选
    await new Promise(resolve => setTimeout(resolve, 1500))
    
    candidateIds.forEach(id => {
      const candidate = candidates.value.find(c => c.id === id)
      if (candidate && candidate.status === 'pending') {
        // 根据匹配度自动判断
        candidate.status = candidate.matchScore >= 75 ? 'passed' : 'rejected'
        candidate.reviewedAt = new Date()
      }
    })
    
    isLoading.value = false
  }

  const openModal = () => {
    isModalOpen.value = true
  }

  const closeModal = () => {
    isModalOpen.value = false
    currentJob.value = null
  }

  const setCurrentJob = (job: Job | null) => {
    currentJob.value = job
  }

  const setCurrentCandidate = (candidate: Candidate | null) => {
    currentCandidate.value = candidate
  }

  const addInterview = (interviewData: Omit<Interview, 'id' | 'createdAt'>) => {
    const newInterview: Interview = {
      ...interviewData,
      id: Date.now().toString(),
      createdAt: new Date()
    }
    interviews.value.push(newInterview)
  }

  const pauseJob = (jobId: string) => {
    const job = jobs.value.find(j => j.id === jobId)
    if (job) {
      job.status = 'paused'
      job.updatedAt = new Date()
    }
  }

  const resumeJob = (jobId: string) => {
    const job = jobs.value.find(j => j.id === jobId)
    if (job) {
      job.status = 'active'
      job.updatedAt = new Date()
    }
  }

  const deleteJob = (jobId: string) => {
    const index = jobs.value.findIndex(j => j.id === jobId)
    if (index !== -1) {
      jobs.value.splice(index, 1)
      // 同时删除相关的候选人数据
      candidates.value = candidates.value.filter(c => c.jobId !== jobId)
      // 删除相关的面试数据
      //interviews.value = interviews.value.filter(i => i.jobId !== jobId)
    }
  }

  return {
    // 状态
    jobs,
    candidates,
    interviews,
    isModalOpen,
    isLoading,
    currentJob,
    currentCandidate,
    
    // 计算属性
    activeJobs,
    totalPendingResumes,
    totalCandidates,
    pendingCandidates,
    passedCandidates,
    rejectedCandidates,
    interviewedCandidates,
    getCandidatesByJob,
    getJobById,
    dashboardStats,
    
    // 动作
    initializeData,
    addJob,
    updateJob,
    triggerScreening,
    updateCandidateStatus,
    batchScreenCandidates,
    openModal,
    closeModal,
    setCurrentJob,
    setCurrentCandidate,
    addInterview,
    pauseJob,
    resumeJob,
    deleteJob
  }
})